@@ -1,5 +1,4 @@
-""" Async code checking.
-"""
+""" Async code checking. """
 import logging
 import threading
 from os import path as op
@@ -80,7 +79,7 @@ def async_check_files(paths, options, rootpath=None):
     return errors
 
 
-def check_path(path, options=None, rootpath=None):
+def check_path(path, options=None, rootpath=None, **meta):
     """ Check path.
 
     :return list: list of errors
@@ -100,7 +99,7 @@ def check_path(path, options=None, rootpath=None):
     for error in run(
         path, ignore=options.ignore, select=options.select,
         linters=options.linters, complexity=options.complexity,
-            config=config):
+            config=config, **meta):
         try:
             error['rel'] = op.relpath(error['filename'], rootpath)
             error['col'] = error.get('col', 1)
